@@ -166,7 +166,48 @@ _gtk_marshal_BOOLEAN__ENUM (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,UINT,UINT (gtkmarshalers.list:27) */
+/* BOOLEAN:ENUM,INT (gtkmarshalers.list:27) */
+void
+_gtk_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
+                                GValue       *return_value,
+                                guint         n_param_values,
+                                const GValue *param_values,
+                                gpointer      invocation_hint,
+                                gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__ENUM_INT) (gpointer     data1,
+                                                      gint         arg_1,
+                                                      gint         arg_2,
+                                                      gpointer     data2);
+  register GMarshalFunc_BOOLEAN__ENUM_INT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__ENUM_INT) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_enum (param_values + 1),
+                       g_marshal_value_peek_int (param_values + 2),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* BOOLEAN:OBJECT,UINT,UINT (gtkmarshalers.list:28) */
 void
 _gtk_marshal_BOOLEAN__OBJECT_UINT_UINT (GClosure     *closure,
                                         GValue       *return_value,
@@ -209,7 +250,7 @@ _gtk_marshal_BOOLEAN__OBJECT_UINT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,INT,INT,UINT (gtkmarshalers.list:28) */
+/* BOOLEAN:OBJECT,INT,INT,UINT (gtkmarshalers.list:29) */
 void
 _gtk_marshal_BOOLEAN__OBJECT_INT_INT_UINT (GClosure     *closure,
                                            GValue       *return_value,
@@ -254,7 +295,7 @@ _gtk_marshal_BOOLEAN__OBJECT_INT_INT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,STRING,STRING,BOXED (gtkmarshalers.list:29) */
+/* BOOLEAN:OBJECT,STRING,STRING,BOXED (gtkmarshalers.list:30) */
 void
 _gtk_marshal_BOOLEAN__OBJECT_STRING_STRING_BOXED (GClosure     *closure,
                                                   GValue       *return_value,
@@ -299,7 +340,7 @@ _gtk_marshal_BOOLEAN__OBJECT_STRING_STRING_BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,BOXED,BOXED (gtkmarshalers.list:30) */
+/* BOOLEAN:OBJECT,BOXED,BOXED (gtkmarshalers.list:31) */
 void
 _gtk_marshal_BOOLEAN__OBJECT_BOXED_BOXED (GClosure     *closure,
                                           GValue       *return_value,
@@ -342,7 +383,7 @@ _gtk_marshal_BOOLEAN__OBJECT_BOXED_BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:INT,INT (gtkmarshalers.list:31) */
+/* BOOLEAN:INT,INT (gtkmarshalers.list:32) */
 void
 _gtk_marshal_BOOLEAN__INT_INT (GClosure     *closure,
                                GValue       *return_value,
@@ -383,7 +424,7 @@ _gtk_marshal_BOOLEAN__INT_INT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (gtkmarshalers.list:32) */
+/* BOOLEAN:VOID (gtkmarshalers.list:33) */
 void
 _gtk_marshal_BOOLEAN__VOID (GClosure     *closure,
                             GValue       *return_value,
@@ -420,7 +461,7 @@ _gtk_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:BOOLEAN (gtkmarshalers.list:33) */
+/* BOOLEAN:BOOLEAN (gtkmarshalers.list:34) */
 void
 _gtk_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                GValue       *return_value,
@@ -459,7 +500,7 @@ _gtk_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* ENUM:ENUM (gtkmarshalers.list:34) */
+/* ENUM:ENUM (gtkmarshalers.list:35) */
 void
 _gtk_marshal_ENUM__ENUM (GClosure     *closure,
                          GValue       *return_value,
@@ -498,7 +539,7 @@ _gtk_marshal_ENUM__ENUM (GClosure     *closure,
   g_value_set_enum (return_value, v_return);
 }
 
-/* INT:POINTER (gtkmarshalers.list:35) */
+/* INT:POINTER (gtkmarshalers.list:36) */
 void
 _gtk_marshal_INT__POINTER (GClosure     *closure,
                            GValue       *return_value,
@@ -537,13 +578,13 @@ _gtk_marshal_INT__POINTER (GClosure     *closure,
   g_value_set_int (return_value, v_return);
 }
 
-/* NONE:BOOLEAN (gtkmarshalers.list:36) */
+/* NONE:BOOLEAN (gtkmarshalers.list:37) */
 
-/* NONE:ENUM (gtkmarshalers.list:37) */
+/* NONE:ENUM (gtkmarshalers.list:38) */
 
-/* NONE:INT (gtkmarshalers.list:38) */
+/* NONE:INT (gtkmarshalers.list:39) */
 
-/* NONE:INT,BOOL (gtkmarshalers.list:39) */
+/* NONE:INT,BOOL (gtkmarshalers.list:40) */
 void
 _gtk_marshal_VOID__INT_BOOLEAN (GClosure     *closure,
                                 GValue       *return_value,
@@ -580,7 +621,7 @@ _gtk_marshal_VOID__INT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* NONE:INT,INT (gtkmarshalers.list:40) */
+/* NONE:INT,INT (gtkmarshalers.list:41) */
 void
 _gtk_marshal_VOID__INT_INT (GClosure     *closure,
                             GValue       *return_value,
@@ -617,9 +658,9 @@ _gtk_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* NONE:NONE (gtkmarshalers.list:41) */
+/* NONE:NONE (gtkmarshalers.list:42) */
 
-/* NONE:STRING,INT,POINTER (gtkmarshalers.list:42) */
+/* NONE:STRING,INT,POINTER (gtkmarshalers.list:43) */
 void
 _gtk_marshal_VOID__STRING_INT_POINTER (GClosure     *closure,
                                        GValue       *return_value,
@@ -658,7 +699,7 @@ _gtk_marshal_VOID__STRING_INT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* STRING:DOUBLE (gtkmarshalers.list:43) */
+/* STRING:DOUBLE (gtkmarshalers.list:44) */
 void
 _gtk_marshal_STRING__DOUBLE (GClosure     *closure,
                              GValue       *return_value,
@@ -697,11 +738,11 @@ _gtk_marshal_STRING__DOUBLE (GClosure     *closure,
   g_value_set_string_take_ownership (return_value, v_return);
 }
 
-/* VOID:DOUBLE (gtkmarshalers.list:44) */
+/* VOID:DOUBLE (gtkmarshalers.list:45) */
 
-/* VOID:BOOLEAN (gtkmarshalers.list:45) */
+/* VOID:BOOLEAN (gtkmarshalers.list:46) */
 
-/* VOID:BOOLEAN,BOOLEAN,BOOLEAN (gtkmarshalers.list:46) */
+/* VOID:BOOLEAN,BOOLEAN,BOOLEAN (gtkmarshalers.list:47) */
 void
 _gtk_marshal_VOID__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                             GValue       *return_value,
@@ -740,9 +781,9 @@ _gtk_marshal_VOID__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED (gtkmarshalers.list:47) */
+/* VOID:BOXED (gtkmarshalers.list:48) */
 
-/* VOID:BOXED,BOXED (gtkmarshalers.list:48) */
+/* VOID:BOXED,BOXED (gtkmarshalers.list:49) */
 void
 _gtk_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                 GValue       *return_value,
@@ -779,7 +820,7 @@ _gtk_marshal_VOID__BOXED_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,BOXED,POINTER (gtkmarshalers.list:49) */
+/* VOID:BOXED,BOXED,POINTER (gtkmarshalers.list:50) */
 void
 _gtk_marshal_VOID__BOXED_BOXED_POINTER (GClosure     *closure,
                                         GValue       *return_value,
@@ -818,7 +859,7 @@ _gtk_marshal_VOID__BOXED_BOXED_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,OBJECT (gtkmarshalers.list:50) */
+/* VOID:BOXED,OBJECT (gtkmarshalers.list:51) */
 void
 _gtk_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                  GValue       *return_value,
@@ -855,7 +896,7 @@ _gtk_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,STRING,INT (gtkmarshalers.list:51) */
+/* VOID:BOXED,STRING,INT (gtkmarshalers.list:52) */
 void
 _gtk_marshal_VOID__BOXED_STRING_INT (GClosure     *closure,
                                      GValue       *return_value,
@@ -894,7 +935,7 @@ _gtk_marshal_VOID__BOXED_STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,UINT (gtkmarshalers.list:52) */
+/* VOID:BOXED,UINT (gtkmarshalers.list:53) */
 void
 _gtk_marshal_VOID__BOXED_UINT (GClosure     *closure,
                                GValue       *return_value,
@@ -931,7 +972,7 @@ _gtk_marshal_VOID__BOXED_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,UINT,FLAGS (gtkmarshalers.list:53) */
+/* VOID:BOXED,UINT,FLAGS (gtkmarshalers.list:54) */
 void
 _gtk_marshal_VOID__BOXED_UINT_FLAGS (GClosure     *closure,
                                      GValue       *return_value,
@@ -970,7 +1011,7 @@ _gtk_marshal_VOID__BOXED_UINT_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,UINT,UINT (gtkmarshalers.list:54) */
+/* VOID:BOXED,UINT,UINT (gtkmarshalers.list:55) */
 void
 _gtk_marshal_VOID__BOXED_UINT_UINT (GClosure     *closure,
                                     GValue       *return_value,
@@ -1009,9 +1050,9 @@ _gtk_marshal_VOID__BOXED_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM (gtkmarshalers.list:55) */
+/* VOID:ENUM (gtkmarshalers.list:56) */
 
-/* VOID:ENUM,BOOLEAN (gtkmarshalers.list:56) */
+/* VOID:ENUM,BOOLEAN (gtkmarshalers.list:57) */
 void
 _gtk_marshal_VOID__ENUM_BOOLEAN (GClosure     *closure,
                                  GValue       *return_value,
@@ -1048,7 +1089,7 @@ _gtk_marshal_VOID__ENUM_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,ENUM (gtkmarshalers.list:57) */
+/* VOID:ENUM,ENUM (gtkmarshalers.list:58) */
 void
 _gtk_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                               GValue       *return_value,
@@ -1085,7 +1126,7 @@ _gtk_marshal_VOID__ENUM_ENUM (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,FLOAT (gtkmarshalers.list:58) */
+/* VOID:ENUM,FLOAT (gtkmarshalers.list:59) */
 void
 _gtk_marshal_VOID__ENUM_FLOAT (GClosure     *closure,
                                GValue       *return_value,
@@ -1122,7 +1163,7 @@ _gtk_marshal_VOID__ENUM_FLOAT (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,FLOAT,BOOLEAN (gtkmarshalers.list:59) */
+/* VOID:ENUM,FLOAT,BOOLEAN (gtkmarshalers.list:60) */
 void
 _gtk_marshal_VOID__ENUM_FLOAT_BOOLEAN (GClosure     *closure,
                                        GValue       *return_value,
@@ -1161,7 +1202,7 @@ _gtk_marshal_VOID__ENUM_FLOAT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,INT (gtkmarshalers.list:60) */
+/* VOID:ENUM,INT (gtkmarshalers.list:61) */
 void
 _gtk_marshal_VOID__ENUM_INT (GClosure     *closure,
                              GValue       *return_value,
@@ -1198,7 +1239,7 @@ _gtk_marshal_VOID__ENUM_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,INT,BOOLEAN (gtkmarshalers.list:61) */
+/* VOID:ENUM,INT,BOOLEAN (gtkmarshalers.list:62) */
 void
 _gtk_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                      GValue       *return_value,
@@ -1237,11 +1278,11 @@ _gtk_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT (gtkmarshalers.list:62) */
+/* VOID:INT (gtkmarshalers.list:63) */
 
-/* VOID:INT,INT (gtkmarshalers.list:63) */
+/* VOID:INT,INT (gtkmarshalers.list:64) */
 
-/* VOID:INT,INT,BOXED (gtkmarshalers.list:64) */
+/* VOID:INT,INT,BOXED (gtkmarshalers.list:65) */
 void
 _gtk_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
                                   GValue       *return_value,
@@ -1280,7 +1321,7 @@ _gtk_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT,INT (gtkmarshalers.list:65) */
+/* VOID:INT,INT,INT (gtkmarshalers.list:66) */
 void
 _gtk_marshal_VOID__INT_INT_INT (GClosure     *closure,
                                 GValue       *return_value,
@@ -1319,9 +1360,9 @@ _gtk_marshal_VOID__INT_INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT (gtkmarshalers.list:66) */
+/* VOID:OBJECT (gtkmarshalers.list:67) */
 
-/* VOID:OBJECT,BOOLEAN (gtkmarshalers.list:67) */
+/* VOID:OBJECT,BOOLEAN (gtkmarshalers.list:68) */
 void
 _gtk_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                    GValue       *return_value,
@@ -1358,7 +1399,7 @@ _gtk_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOXED,BOXED (gtkmarshalers.list:68) */
+/* VOID:OBJECT,BOXED,BOXED (gtkmarshalers.list:69) */
 void
 _gtk_marshal_VOID__OBJECT_BOXED_BOXED (GClosure     *closure,
                                        GValue       *return_value,
@@ -1397,7 +1438,7 @@ _gtk_marshal_VOID__OBJECT_BOXED_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOXED,UINT,UINT (gtkmarshalers.list:69) */
+/* VOID:OBJECT,BOXED,UINT,UINT (gtkmarshalers.list:70) */
 void
 _gtk_marshal_VOID__OBJECT_BOXED_UINT_UINT (GClosure     *closure,
                                            GValue       *return_value,
@@ -1438,7 +1479,7 @@ _gtk_marshal_VOID__OBJECT_BOXED_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,INT,INT (gtkmarshalers.list:70) */
+/* VOID:OBJECT,INT,INT (gtkmarshalers.list:71) */
 void
 _gtk_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                    GValue       *return_value,
@@ -1477,7 +1518,7 @@ _gtk_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (gtkmarshalers.list:71) */
+/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (gtkmarshalers.list:72) */
 void
 _gtk_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
                                                    GValue       *return_value,
@@ -1522,7 +1563,7 @@ _gtk_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT (gtkmarshalers.list:72) */
+/* VOID:OBJECT,OBJECT (gtkmarshalers.list:73) */
 void
 _gtk_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                   GValue       *return_value,
@@ -1559,7 +1600,7 @@ _gtk_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,STRING,STRING (gtkmarshalers.list:73) */
+/* VOID:OBJECT,STRING,STRING (gtkmarshalers.list:74) */
 void
 _gtk_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
                                          GValue       *return_value,
@@ -1598,7 +1639,7 @@ _gtk_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,UINT (gtkmarshalers.list:74) */
+/* VOID:OBJECT,UINT (gtkmarshalers.list:75) */
 void
 _gtk_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                 GValue       *return_value,
@@ -1635,7 +1676,7 @@ _gtk_marshal_VOID__OBJECT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,UINT,FLAGS (gtkmarshalers.list:75) */
+/* VOID:OBJECT,UINT,FLAGS (gtkmarshalers.list:76) */
 void
 _gtk_marshal_VOID__OBJECT_UINT_FLAGS (GClosure     *closure,
                                       GValue       *return_value,
@@ -1674,9 +1715,9 @@ _gtk_marshal_VOID__OBJECT_UINT_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER (gtkmarshalers.list:76) */
+/* VOID:POINTER (gtkmarshalers.list:77) */
 
-/* VOID:POINTER,INT (gtkmarshalers.list:77) */
+/* VOID:POINTER,INT (gtkmarshalers.list:78) */
 void
 _gtk_marshal_VOID__POINTER_INT (GClosure     *closure,
                                 GValue       *return_value,
@@ -1713,7 +1754,7 @@ _gtk_marshal_VOID__POINTER_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER,POINTER (gtkmarshalers.list:78) */
+/* VOID:POINTER,POINTER,POINTER (gtkmarshalers.list:79) */
 void
 _gtk_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                             GValue       *return_value,
@@ -1752,7 +1793,7 @@ _gtk_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,UINT (gtkmarshalers.list:79) */
+/* VOID:POINTER,UINT (gtkmarshalers.list:80) */
 void
 _gtk_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                  GValue       *return_value,
@@ -1789,9 +1830,9 @@ _gtk_marshal_VOID__POINTER_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING (gtkmarshalers.list:80) */
+/* VOID:STRING (gtkmarshalers.list:81) */
 
-/* VOID:STRING,STRING (gtkmarshalers.list:81) */
+/* VOID:STRING,STRING (gtkmarshalers.list:82) */
 void
 _gtk_marshal_VOID__STRING_STRING (GClosure     *closure,
                                   GValue       *return_value,
@@ -1828,9 +1869,9 @@ _gtk_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT,POINTER (gtkmarshalers.list:82) */
+/* VOID:STRING,INT,POINTER (gtkmarshalers.list:83) */
 
-/* VOID:UINT,UINT (gtkmarshalers.list:83) */
+/* VOID:UINT,UINT (gtkmarshalers.list:84) */
 void
 _gtk_marshal_VOID__UINT_UINT (GClosure     *closure,
                               GValue       *return_value,
@@ -1867,7 +1908,7 @@ _gtk_marshal_VOID__UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,UINT,BOXED (gtkmarshalers.list:84) */
+/* VOID:UINT,UINT,BOXED (gtkmarshalers.list:85) */
 void
 _gtk_marshal_VOID__UINT_UINT_BOXED (GClosure     *closure,
                                     GValue       *return_value,
@@ -1906,7 +1947,7 @@ _gtk_marshal_VOID__UINT_UINT_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,STRING (gtkmarshalers.list:85) */
+/* VOID:UINT,STRING (gtkmarshalers.list:86) */
 void
 _gtk_marshal_VOID__UINT_STRING (GClosure     *closure,
                                 GValue       *return_value,
@@ -1943,7 +1984,7 @@ _gtk_marshal_VOID__UINT_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,BOXED,UINT,FLAGS,FLAGS (gtkmarshalers.list:86) */
+/* VOID:UINT,BOXED,UINT,FLAGS,FLAGS (gtkmarshalers.list:87) */
 void
 _gtk_marshal_VOID__UINT_BOXED_UINT_FLAGS_FLAGS (GClosure     *closure,
                                                 GValue       *return_value,
@@ -1986,7 +2027,7 @@ _gtk_marshal_VOID__UINT_BOXED_UINT_FLAGS_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,OBJECT,UINT,FLAGS,FLAGS (gtkmarshalers.list:87) */
+/* VOID:UINT,OBJECT,UINT,FLAGS,FLAGS (gtkmarshalers.list:88) */
 void
 _gtk_marshal_VOID__UINT_OBJECT_UINT_FLAGS_FLAGS (GClosure     *closure,
                                                  GValue       *return_value,
@@ -2029,5 +2070,5 @@ _gtk_marshal_VOID__UINT_OBJECT_UINT_FLAGS_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:VOID (gtkmarshalers.list:88) */
+/* VOID:VOID (gtkmarshalers.list:89) */
 
